@@ -7,7 +7,7 @@ import click
 from termcolor import colored
 
 from james import __version__
-from james.utils import cmd, timeit, PythonVersionType
+from james.utils import check_path, cmd, timeit, PythonVersionType
 from james.config import IgniteConfig, IgniteInvalidStateError
 from james.azure import AzureSetup
 from james.james import Ignition
@@ -281,12 +281,21 @@ def status(ctx: click.Context) -> None:
 
 @main.command()
 @click.pass_context
-def review(ctx: click.Context) -> None:
+@click.argument('directory')
+def review(ctx: click.Context, directory: str = None) -> None:
     """
     Linting / code review
     """
-    #if ctx.obj.filename.parent
-    report = CodeInspection(Path.cwd())()
+    # if directory is None:
+    #     path = Path.cwd()
+    # else:
+    #     path = Path(directory)
+    #     if not path.is_dir():
+    #         raise ValueError(f'Path {directory} is not a valid directory')
+    path = check_path(directory or Path.cwd(), check_dir=True)
+
+    inspection = CodeInspection(path=path)
+    report = inspection()
     click.echo(report)
 
 
