@@ -18,7 +18,7 @@ from james.utils import cmd
 class CodeInspection:
 
     FILENAME: str = 'codereview.log'
-    EXCLUDE_PATTERN: str = '.git,.eggs,__pycache__,.tox,docs,test,tests,.pytest_cache'
+    EXCLUDE_PATTERN: str = '.git,.eggs,__pycache__,.tox,build,docs,test,tests,.pytest_cache'
     IGNORE_PATTERN: str = 'D200,D205,D212,D213,D415'
     TYPE_HINT_CHECKS: List[str] = [
         'Function is missing a type annotation',
@@ -28,8 +28,8 @@ class CodeInspection:
     ]
 
     def __init__(self, path: Union[Path, str], check_types: bool = True) -> None:
-        logger.info(f'Starting code inspection for directory {path}')
-        self.path: Path = Path(path)
+        self.path = Path(path)
+        logger.info(f'Starting code inspection for directory {self.path.resolve()}')
         self.flg_check_types = check_types
         self.counts: Dict = {}
         self.totals = {
@@ -77,7 +77,7 @@ class CodeInspection:
             --ignore={self.IGNORE_PATTERN} \
             --max-line-length=120 \
             --docstring-convention=google \
-            .', 
+            {self.path}', 
             no_error=True
         )
         
