@@ -1,7 +1,8 @@
 """
 Utilities
 """
-from typing import Dict, Union
+from typing import Dict, Union, Callable
+from pathlib import Path
 import subprocess
 import re
 import time
@@ -48,6 +49,29 @@ def az_cmd(command: str, params: Dict, **kwargs) -> Union[str, bool]:
     return cmd(full_command, **kwargs)
 
 
+def check_path(
+    path: Union[str, Path], 
+    resolve: bool = True, 
+    check_exists: bool = False, 
+    check_file: bool = False, 
+    check_dir: bool = False
+) -> Path:
+    if isinstance(path, str) and '~' in path:
+        path = path.replace('~', Path.home())
+    
+    if resolve:
+        path = Path(path).resolve()
+    
+    if check_dir:
+        assert path.is_dir()
+    elif check_file:
+        assert path.is_file()
+    elif check_exists:
+        assert path.exists()
+
+    return path
+    
+
 class ProjectNameType(click.ParamType):
     """
     Custom CLI parameter type for Python version specification
@@ -99,4 +123,25 @@ def timeit(units='s', method=logger.info):
             method(msg)
             return res
         return wrapper
-    return timeit_decorator
\ No newline at end of file
+    return timeit_decorator
+
+
+class Timer:
+
+    def __init__(self):
+        self.time = time.time()
+
+    def __call__(self, msg: str = None, update: bool = True, method: Callable = logger.info) -> None:
+        new_time = time.time()
+        diff = new_time - self.time
+
+        # update last timestamp
+        if update:
+            self.time = new_time
+
+        if diff < 1.:
+            duration = f'{diff * 1000:.0f} ms'
+        else:
+            duration = f'{diff:.1f} seconds'
+
+        method(f'Time elapsed: {duration} at checkpoint {msg}')
